@@ -162,7 +162,8 @@ make.kernel <- function (
 {
     if (inherits(movementmodel, 'openCR')) {
         fit <- movementmodel
-        if (fit$movementmodel %in% c('normal','exponential','t2D','uniform','annular')) {
+        if (fit$movementmodel %in% c('normal','exponential','t2D','uniform','annular',
+            'BVN','BVE','BVT')) {
             pred <- predict(fit, ...)
             kernel <- make.kernel(
                 movementmodel = fit$movementmodel, 
@@ -191,13 +192,14 @@ make.kernel <- function (
             usermodel <- NULL
             movementmodel <- match.arg(movementmodel[1],
                 choices = c('normal','exponential','t2D','uniform','annular',
+                    'BVN','BVE','BVT',
                     'annular2','annularR')) 
         }
         if (missing(move.a) && movementmodel %in% c('normal','exponential','t2D','annular',
-            'annular2', 'annularR')) { 
+            'annular2', 'annularR', 'BVN','BVE','BVT')) { 
             stop ("move.a required for movementmodel ", movementmodel)
         }
-        if (missing(move.b) && movementmodel %in% c('t2D','annular2','annularR')) {
+        if (missing(move.b) && movementmodel %in% c('t2D','annular2','annularR', 'BVT')) {
             stop ("move.b required for movementmodel ", movementmodel)
         }
         # if (missing(move.b) && zeroinflated) {
@@ -281,6 +283,7 @@ getpstring <- function (movementmodel, move.a, move.b, sep = ' ') {
     npar <- switch(movementmodel, static = 0, uncorrelated = 0, 
         normal = 1, exponential = 1, t2D = 2, 
         uniform = 0, annular = 1, annular2 = 2, annularR = 2, 
+        BVN = 1, BVE = 1, BVT = 2,
         0)
     pstring <- ''
     if (npar>0) pstring <- paste0('move.a = ', move.a)
@@ -296,7 +299,8 @@ plot.kernel <- function (x, contour = FALSE, levels = NULL, text = FALSE, title
     movementmodel <- attr(x, 'movementmodel')
     npar <- switch(movementmodel, static = 0, uncorrelated = 0, normal = 1, 
         exponential = 1, t2D = 2, uniform = 0, annular = 1, annular2 = 2, 
-        annularR = 2)
+        annularR = 2,
+        BVN = 1, BVE = 1, BVT = 2)
     pstring <- getpstring(movementmodel, round(move.a,3), round(move.b,3))
     kernelp <- covariates(x)$kernelp
     dots <- list(...)
@@ -356,12 +360,13 @@ ed <- function(movementmodel = c('normal', 'exponential', 't2D', 'uniform',
     'annular', 'annular2', 'annularR'), move.a, move.b, radius) {
     if (movementmodel=='user') return (NA)  # 2020-10-06
     movementmodel <- match.arg(movementmodel[1], choices = c('normal',
-        'exponential', 't2D', 'uniform', 'annular', 'annular2', 'annularR'))
-    if (movementmodel %in% c('normal'))
+        'exponential', 't2D', 'uniform', 'annular', 'annular2', 'annularR',
+        'BVN', 'BVE', 'BVT'))
+    if (movementmodel %in% c('normal', 'BVN'))
         move.a * (pi/2)^0.5         ## Nathan et al 2012 Table 15.1
-    else if (movementmodel %in% c('exponential'))
+    else if (movementmodel %in% c('exponential', 'BVE'))
         move.a * 2              ## Nathan et al 2012 Table 15.1
-    else if (movementmodel %in% c('t2D')) {
+    else if (movementmodel %in% c('t2D', 'BVT')) {
         if (missing(move.b)) stop ("t2D model has two parameters")
         a <- move.a
         b <- move.b + 1
@@ -386,15 +391,16 @@ bR <- function(R, movementmodel = c('normal', 'exponential', 't2D', 'uniform',
     'annular', 'annular2', 'annularR'), move.a, move.b) {
     if (movementmodel=='user') return (NA)  # 2020-10-06
     movementmodel <- match.arg(movementmodel[1], choices = c('normal',
-        'exponential','t2D','uniform','annular', 'annular2', 'annularR')) 
-    if (movementmodel %in% c('normal')) {
+        'exponential','t2D','uniform','annular', 'annular2', 'annularR',
+        'BVN','BVE','BVT')) 
+    if (movementmodel %in% c('normal', 'BVN')) {
         alpha <- move.a
         exp(-R^2/alpha^2/2)
     }
-    else if (movementmodel %in% c('exponential')) {
+    else if (movementmodel %in% c('exponential', 'BVE')) {
         (R/move.a + 1) * exp(-R/move.a)   # fixed 2021-02-22
     }
-    else if (movementmodel %in% c('t2D')) {
+    else if (movementmodel %in% c('t2D', 'BVT')) {
         if (missing(move.b)) stop ("t2D model has two parameters")
         a <- move.a
         b <- move.b + 1
@@ -456,13 +462,13 @@ quantile.kernel <- function (x, probs = seq(0, 1, 0.25), na.rm = FALSE,
     movementmodel <- attr(x, 'movementmodel')
     move.a <- attr(x, 'move.a')
     move.b <- attr(x, 'move.b')
-    if (movementmodel == 'normal') {
+    if (movementmodel %in% c('normal', 'BVN')) {
         pfn <- function(R, q) (1-exp(-R^2/2/move.a^2))-q
     }    
-    else if (movementmodel == 'exponential') {
+    else if (movementmodel %in% c('exponential', 'BVE')) {
         pfn <- function(R, q) (1-(R/move.a+1) * exp(-R/move.a))-q
     }
-    else if (movementmodel == 't2D') {
+    else if (movementmodel %in% c('t2D', 'BVT')) {
         pfn <- function(R, q) (1-(move.a^2/(move.a^2+R^2))^move.b)-q
     }
     upper <- 1e5*move.a
@@ -490,20 +496,21 @@ empirical <- function (kernel) {
 # Distribution function for distance moved
 dkernel <- function (r, movementmodel = c('normal','exponential','t2D'),
     move.a, move.b, truncate = Inf) {
-    movementmodel <- match.arg(movementmodel)
+    movementmodel <- match.arg(movementmodel, choices = c('normal','exponential',
+        't2D', 'BVN', 'BVE','BVT'))
     movementmodel <- try(match.arg(movementmodel), silent = TRUE)
     if (inherits(movementmodel, 'try-error')) {
         warning("dkernel defined only for movement models normal, exponential, t2D")
         rep(NA, length(r))
     }
     else {
-        if (movementmodel == 'normal') {
+        if (movementmodel %in% c('normal', 'BVN')) {
             d <- r/move.a^2 * exp(-r^2/2/move.a^2)
         }    
-        else if (movementmodel == 'exponential') {
+        else if (movementmodel %in% c('exponential', 'BVE')) {
             d <- r/move.a^2 * exp(-r/move.a)
         }
-        else if (movementmodel == 't2D') {
+        else if (movementmodel %in% c('t2D', 'BVT')) {
             d <- 2 * move.b * r / move.a^2 * (1 + r^2/move.a^2)^-(move.b+1)
         }
         else {
@@ -523,19 +530,20 @@ dkernel <- function (r, movementmodel = c('normal','exponential','t2D'),
 # Distribution function for distance moved
 pkernel <- function (q, movementmodel = c('normal','exponential','t2D'),
     move.a, move.b, truncate = Inf, lower.tail = TRUE) {
-    movementmodel <- try(match.arg(movementmodel), silent = TRUE)
+    movementmodel <- try(match.arg(movementmodel, choices = c('normal',
+        'exponential', 't2D', 'BVN', 'BVE','BVT')), silent = TRUE)
     if (inherits(movementmodel, 'try-error')) {
         warning("pkernel defined only for movement models normal, exponential, t2D")
         rep(NA, length(q))
     }
     else {
-        if (movementmodel == 'normal') {
+        if (movementmodel %in% c('normal', 'BVN')) {
             p <- exp(-q^2/2/move.a^2)
         }    
-        else if (movementmodel == 'exponential') {
+        else if (movementmodel %in% c('exponential', 'BVE')) {
             p <- (q/move.a+1) * exp(-q/move.a)
         }
-        else if (movementmodel == 't2D') {
+        else if (movementmodel %in% c('t2D', 'BVT')) {
             p <- (move.a^2/(move.a^2+q^2))^move.b
         }
         else {
@@ -555,7 +563,8 @@ pkernel <- function (q, movementmodel = c('normal','exponential','t2D'),
 
 qkernel <- function(p, movementmodel = c('normal','exponential','t2D'),
     move.a, move.b, truncate = Inf, lower.tail = TRUE) {
-    movementmodel <- try(match.arg(movementmodel), silent = TRUE)
+    movementmodel <- try(match.arg(movementmodel, choices = c('normal',
+        'exponential', 't2D', 'BVN', 'BVE','BVT')), silent = TRUE)
     if (inherits(movementmodel, 'try-error')) {
         warning("qkernel defined only for movement models normal, exponential, t2D")
         rep(NA, length(p))
@@ -569,10 +578,10 @@ qkernel <- function(p, movementmodel = c('normal','exponential','t2D'),
         if (lower.tail) {
             p <- 1-p
         }
-        if (movementmodel == 'normal') {
+        if (movementmodel %in% c('normal','BVN')) {
             q <- sqrt(-log(p)*2*move.a^2)
         }    
-        else if (movementmodel == 'exponential') {
+        else if (movementmodel %in% c('exponential', 'BVE')) {
             # p <- (q/move.a+1) * exp(-q/move.a)
             # Doesn't work W <- VGAM::lambertW(-p/exp(1))
             # q <- (-W - 1) * move.a
@@ -586,7 +595,7 @@ qkernel <- function(p, movementmodel = c('normal','exponential','t2D'),
             }
             q <- sapply(p, onep)
         }
-        else if (movementmodel == 't2D') {
+        else if (movementmodel %in% c('t2D', 'BVT')) {
             q <- move.a * sqrt(p^(-1/move.b) - 1)
         }
         else {
@@ -607,13 +616,13 @@ qkernel <- function(p, movementmodel = c('normal','exponential','t2D'),
 # pkernel(100, 'uniform', 33.97, 1)
 
 matchscale <- function(movementmodel, q = 40, p = 0.5, lower = 1e-5, upper = 1e5, move.b = 1) {
-    if (movementmodel == 'normal') {
+    if (movementmodel %in% c('normal', 'BVN')) {
         mfn <- function(move.a) (1-exp(-q^2/2/move.a^2))-p
     }    
-    else if (movementmodel == 'exponential') {
+    else if (movementmodel %in% c('exponential', 'BVE')) {
         mfn <- function(move.a) (1-(q/move.a+1) * exp(-q/move.a))-p
     }
-    else if (movementmodel == 't2D') {
+    else if (movementmodel %in% c('t2D', 'BVT')) {
         mfn <- function(move.a) (1-(move.a^2/(move.a^2+q^2))^move.b)-p
     }
     out <- try(uniroot(mfn, c(lower,upper))$root, silent = TRUE)
