@@ -174,7 +174,7 @@ open.secr.loglikfn <- function (beta, dig = 3, betaw = 8, oneeval = FALSE, data)
         gk <- array(temp[[1]], dim=c(nrow(realparval), stratum$k, stratum$m))  # array form for R use
         hk <- array(temp[[2]], dim=c(nrow(realparval), stratum$k, stratum$m))  # array form for R use
         if (sum(hk)==0) {
-            return(1e10)
+            return(NA)   # changed from 1e10 2021-06-01
         }
         
         if (data$details$debug>0) message ("sum(gk) = ", sum(gk))
