@@ -49,7 +49,7 @@ openCR.fit <- function (capthist, type = "CJS", model = list(p~1, phi~1, sigma~1
   #  model      -  formulae for real parameters in terms of effects and covariates
   #  start      -  start values for maximization (numeric vector link scale);
   #  link       -  list of parameter-specific link function names 'log', 'logit', 'loglog',
-  #                'identity', 'sin', 'neglog', 'mlogit'
+  #                'identity', 'sin', 'neglog', 'mlogit', 'log05'
   #  fixed      -  list of fixed values for named parameters
   #  sessioncov -  dataframe of session-level covariates
   #  mask
@@ -70,11 +70,10 @@ openCR.fit <- function (capthist, type = "CJS", model = list(p~1, phi~1, sigma~1
     debug = 0, 
     grain = 1,
     hessian = 'auto', 
+    stepmax = 3,             ## nlm argument; was 10
     ignoreusage = FALSE, 
     initialage = 0, 
     LLonly = FALSE,
-    kernelradius = 10,
-    sparsekernel = FALSE,
     minimumage = 0, 
     maximumage = 1,
     multinom = FALSE,
@@ -84,8 +83,15 @@ openCR.fit <- function (capthist, type = "CJS", model = list(p~1, phi~1, sigma~1
     initialstratum = 1
   )
   
-  if (is.logical(details$hessian))
+  ## check input 'details'
+  if (is.logical(details$hessian)) {
     details$hessian <- ifelse(details$hessian, 'auto', 'none')
+  }
+  if (!is.null(details$kernelradius)) {
+      ## 2021-05-30
+      warning ("kernelradius is now full argument of openCR.fit; value in details ignored")
+  }
+  ##
   details <- replace (defaultdetails, names(details), details)
   if (!is.null(trace)) details$trace <- trace
   if (details$LLonly)  details$trace <- FALSE
@@ -173,7 +179,7 @@ openCR.fit <- function (capthist, type = "CJS", model = list(p~1, phi~1, sigma~1
       # 'annularR' while avoiding need to document it!
       movementmodel <- match.arg(movementmodel[1], 
         choices = c('static','uncorrelated','normal','exponential', 't2D',
-          'uniform', 'annular', 'annular2', 'annularR'))
+          'uniform', 'annular', 'annular2', 'annularR', 'BVN', 'BVE', 'BVT'))
     }
     ## integer code for movement model
     movementcode <- movecode(movementmodel)
@@ -269,11 +275,11 @@ openCR.fit <- function (capthist, type = "CJS", model = list(p~1, phi~1, sigma~1
   
   moveargsi <- c(-2,-2)
   if (secr) {
-    if (movementmodel %in% c('normal','exponential')) {
+    if (movementmodel %in% c('normal', 'exponential', 'BVN', 'BVE')) {
       pnames <- c(pnames, 'move.a')
       moveargsi[1] <- .openCRstuff$sigmai[typecode(type)] + 1 + (detectfn %in% c(15,17,18,19))
     }
-    else if (movementmodel %in% c('t2D', 't2DS')) {
+    else if (movementmodel %in% c('t2D', 't2DS', 'BVT')) {
       pnames <- c(pnames, 'move.a', 'move.b')
       moveargsi[1] <- .openCRstuff$sigmai[typecode(type)] + 1 + (detectfn %in% c(15,17,18,19))
       moveargsi[2] <- moveargsi[1]+1
@@ -751,7 +757,8 @@ openCR.fit <- function (capthist, type = "CJS", model = list(p~1, phi~1, sigma~1
       data     = data,   # environment(),
       betaw    = betaw,
       hessian  = tolower(details$hessian)=='auto',
-      stepmax  = 10)
+      fscale   = 500,    
+      stepmax  = details$stepmax)   ## changed from 10 2021-06-01
     ## cluster  = cluster)
     this.fit <- do.call (nlm, args)
     this.fit$par <- this.fit$estimate     # copy for uniformity
