@@ -134,7 +134,7 @@ classMembership.openCR <- function (object, fullCH = NULL, ...) {
         }
         ##--------------------------------------------------------------
         distmat <- getdistmat(trps, object$mask, object$detectfn==20)
-        temp <- makegkParallelcpp (as.integer(object$detectfn),
+        temp <- makegkParalleldcpp (as.integer(object$detectfn),
                                    as.integer(.openCRstuff$sigmai[type]),
                                    as.integer(object$details$grain),
                                    as.matrix(realparval),
