@@ -38,15 +38,19 @@ typecode <- function (type) {
 }
 
 movecode <- function (movementmodel) {
-    switch (movementmodel, static = 0, uncorrelated = 1, normal = 2, 
+    switch (movementmodel, 
+        static = 0, uncorrelated = 1, normal = 2, 
         exponential = 3, user = 4, t2D = 5, uniform = 6, annular = 7, 
-        annular2 = 8, annularR = 9)
+        annular2 = 8, annularR = 9, 
+        BVN = 2, BVE = 3, BVT = 5        ## added 2021-05-31
+    )
 }
 
 sparsebool <- function(sparsekernel, movementmodel) {
   out <- sparsekernel
   if (is.null(out)) {
-    out <- movementmodel %in% c('normalS', 'exponentialS', 't2DS')  # for short-term backward compatibility
+      # for short-term backward compatibility
+      out <- movementmodel %in% c('normalS', 'exponentialS', 't2DS')  
   }
   out
 }
@@ -331,41 +335,44 @@ invmlogit <- function (x, fillin = TRUE) {
 
 transform <- function (x, link) {
     switch (link,
-            identity = x,
-            log = log(x),
-            neglog = log(-x),
-            logit = logit(x),
-            loglog = -log(-log(x)),
-            # mlogit = x,
-            mlogit = logit(x),   ## 2019-04-20
-            odds = odds(x),
-            sin = sine(x)
+        identity = x,
+        log = log(x),
+        log05 = log(x-0.5),
+        neglog = log(-x),
+        logit = logit(x),
+        loglog = -log(-log(x)),
+        # mlogit = x,
+        mlogit = logit(x),   ## 2019-04-20
+        odds = odds(x),
+        sin = sine(x)
     )
 }
 ############################################################################################
 
 untransform <- function (beta, link) {
     switch (link,
-            identity = beta,
-            log = exp(beta),
-            neglog = -exp(beta),
-            logit = invlogit(beta),
-            loglog = exp(-exp(-beta)),
-            mlogit = beta,   ## delay
-            odds = invodds(beta),
-            sin = invsine(beta))
+        identity = beta,
+        log = exp(beta),
+        log05 = exp(beta) + 0.5,
+        neglog = -exp(beta),
+        logit = invlogit(beta),
+        loglog = exp(-exp(-beta)),
+        mlogit = beta,   ## delay
+        odds = invodds(beta),
+        sin = invsine(beta))
 }
 ############################################################################################
 
 se.untransform <- function (beta, sebeta, link) {
     switch (link,
-            identity = sebeta,
-            log = exp(beta) * sqrt(exp(sebeta^2)-1),
-            neglog = exp(beta) * sqrt(exp(sebeta^2)-1),
-            logit = invlogit(beta) * (1-invlogit(beta)) * sebeta,
-            loglog = -exp(-exp(-beta)) * sebeta * -exp(-beta),
-            mlogit = NA,      ## don't know how
-            sin = NA)         ####!!!!
+        identity = sebeta,
+        log = exp(beta) * sqrt(exp(sebeta^2)-1),
+        log05 =  exp(beta) * sqrt(exp(sebeta^2)-1),
+        neglog = exp(beta) * sqrt(exp(sebeta^2)-1),
+        logit = invlogit(beta) * (1-invlogit(beta)) * sebeta,
+        loglog = -exp(-exp(-beta)) * sebeta * -exp(-beta),
+        mlogit = NA,      ## don't know how
+        sin = NA)         ####!!!!
 }
 ############################################################################################
 
@@ -375,14 +382,15 @@ Xtransform <- function (real, linkfn, varnames) {
     for (i in 1:length(real)) {
         vn <- varnames[i]
         out[i] <- switch (linkfn[[vn]],
-                          identity = real[i],
-                          log = log(real[i]),
-                          neglog = log(-real[i]),
-                          logit = logit(real[i]),
-                          loglog = -log(-log(real[i])),
-                          mlogit = real[i],      ## delay
-                          odds = odds(real[i]),
-                          sin = sine(real[i]))
+            identity = real[i],
+            log = log(real[i]),
+            log05 = log(real[i]-0.5),
+            neglog = log(-real[i]),
+            logit = logit(real[i]),
+            loglog = -log(-log(real[i])),
+            mlogit = real[i],      ## delay
+            odds = odds(real[i]),
+            sin = sine(real[i]))
     }
     out
 }
@@ -393,13 +401,14 @@ se.Xtransform <- function (real, sereal, linkfn, varnames) {
     for (i in 1:length(real)) {
         vn <- varnames[i]
         out[i] <- switch (linkfn[[vn]],
-                          identity = sereal[i],
-                          log = log((sereal[i]/real[i])^2 + 1)^0.5,
-                          neglog = log((sereal[i]/-real[i])^2 + 1)^0.5,
-                          logit = sereal[i] / real[i] / (1 - real[i]),
-                          loglog = -real[i] * sereal[i] * log(real[i]),
-                          mlogit = NA,      ## don't know how
-                          sin = NA)
+            identity = sereal[i],
+            log = log((sereal[i]/real[i])^2 + 1)^0.5,
+            log05 = log((sereal[i]/real[i])^2 + 1)^0.5,
+            neglog = log((sereal[i]/-real[i])^2 + 1)^0.5,
+            logit = sereal[i] / real[i] / (1 - real[i]),
+            loglog = -real[i] * sereal[i] * log(real[i]),
+            mlogit = NA,      ## don't know how
+            sin = NA)
     }
     out
 }
@@ -411,14 +420,15 @@ Xuntransform <- function (beta, linkfn, varnames) {
     for (i in 1:length(beta)) {
         vn <- varnames[i]
         out[i] <- switch (linkfn[[vn]],
-                          identity = beta[i],
-                          log = exp(beta[i]),
-                          neglog = -exp(beta[i]),
-                          logit = invlogit(beta[i]),
-                          loglog = exp(-exp(-beta[i])),
-                          mlogit = beta[i],   # delay
-                          odds = invodds(beta[i]),
-                          sin = invsine(beta[i]))
+            identity = beta[i],
+            log = exp(beta[i]),
+            log05 = exp(beta[i]) + 0.5,
+            neglog = -exp(beta[i]),
+            logit = invlogit(beta[i]),
+            loglog = exp(-exp(-beta[i])),
+            mlogit = beta[i],   # delay
+            odds = invodds(beta[i]),
+            sin = invsine(beta[i]))
     }
     out
 }
@@ -436,13 +446,14 @@ se.Xuntransform <- function (beta, sebeta, linkfn, varnames)
     for (i in 1:length(beta)) {
         vn <- varnames[i]
         out[i] <- switch (linkfn[[vn]],
-                          identity = sebeta[i],
-                          log = exp(beta[i]) * sqrt(exp(sebeta[i]^2)-1),
-                          neglog = exp(beta[i]) * sqrt(exp(sebeta[i]^2)-1),
-                          logit = invlogit(beta[i]) * (1-invlogit(beta[i])) * sebeta[i],
-                          loglog = NA, 
-                          mlogit = NA,    ## don't know how
-                          sin = NA)         ####!!!!
+            identity = sebeta[i],
+            log = exp(beta[i]) * sqrt(exp(sebeta[i]^2)-1),
+            log05 = exp(beta[i]) * sqrt(exp(sebeta[i]^2)-1),
+            neglog = exp(beta[i]) * sqrt(exp(sebeta[i]^2)-1),
+            logit = invlogit(beta[i]) * (1-invlogit(beta[i])) * sebeta[i],
+            loglog = NA, 
+            mlogit = NA,    ## don't know how
+            sin = NA)         ####!!!!
     }
     out
 }
